#!/bin/sh
# i.MX 8M Plus, version V3.0, Phytec 06.2023

init_dev() {

echo " ====================================================================="

if [ -z "$1" ] ; then
	PROC="ISI"
else
	PROC="$1"
fi

if [ "$PROC" = "ISI" ] ; then
	VID_DEVICE="/dev/video-isi-csi1"
elif [ "$PROC" = "ISP" ] ; then
	VID_DEVICE="/dev/video-isp-csi1"
else
	echo ""
	echo "$PROC not supported, only ISI and ISP."
	return 1
fi

if [ -L /dev/cam-csi1 ] ; then
	CAM_DEVICE="/dev/cam-csi1"
elif [ -L /dev/cam-csi1-port0 ] ; then
	CAM_DEVICE="/dev/cam-csi1-port0"
elif [ -L /dev/cam-csi1-port1 ] ; then
	CAM_DEVICE="/dev/cam-csi1-port1"
else
	echo ""
	echo " No camera found on CSI1"
	return 1
fi

CAM_ENT="$(cat /sys/class/video4linux/$(readlink ${CAM_DEVICE})/name)"
CAM_NAME="$(echo ${CAM_ENT} | cut -d" " -f1)"
CAM_I2C_BUS="$(echo ${CAM_ENT} | cut -d" " -f2 | cut -b1)"
CAM_I2C_ADRESS="$(echo ${CAM_ENT} | cut -d" " -f2 | cut -b4-6)"

if [ $CAM_NAME = "ar0144" ]; then
	source /usr/share/phytec-gstreamer-examples/ar0144.conf
elif [ $CAM_NAME = "ar0521" ]; then
	source /usr/share/phytec-gstreamer-examples/ar0521.conf
elif [ $CAM_NAME = "ar0234" ]; then
        source /usr/share/phytec-gstreamer-examples/ar0234.conf
else
	echo ""
	echo " camera at CAM1 connector not found"
	echo " no camera or more then one camera connected"
	echo " please check camera device tree"
	echo " please check connected camera type, i2c adress and cable connections"
	echo ""
	return 1
fi

echo ""
echo " camera = $CAMERA_TYP at i2c bus=$CAM_I2C_BUS with i2c adress=0x$CAM_I2C_ADRESS installed"
echo " capture device @CAM1 = ${VID_DEVICE} --> $(readlink -f ${VID_DEVICE})"
echo " camera device @CAM1 = ${CAM_DEVICE} --> $(readlink -f ${CAM_DEVICE})"
echo " camera entity name = $CAM_ENT"
echo " camera driver = $CAM_NAME"
echo ""

return 0

}

init_dual_dev() {

echo " ====================================================================="

if [ -z "$1" ] ; then
	PROC="ISI"
else
	PROC="$1"
fi

if [ "$PROC" = "ISI" ] ; then
	VID_DEVICE_1="/dev/video-isi-csi1"
elif [ "$PROC" = "ISP" ] ; then
	VID_DEVICE_1="/dev/video-isp-csi1"
else
	echo ""
	echo "$PROC not supported, only ISI and ISP."
	return 1
fi

if [ -L /dev/cam-csi1 ] ; then
        CAM_DEVICE_1="/dev/cam-csi1"
elif [ -L /dev/cam-csi1-port0 ] ; then
        CAM_DEVICE_1="/dev/cam-csi1-port0"
elif [ -L /dev/cam-csi1-port1 ] ; then
        CAM_DEVICE_1="/dev/cam-csi1-port1"
else
        echo ""
        echo " No camera found on CSI1"
        return 1
fi

CAM_ENT_1="$(cat /sys/class/video4linux/$(readlink ${CAM_DEVICE_1})/name)"
CAM_NAME_1="$(echo ${CAM_ENT_1} | cut -d" " -f1)"
CAM_I2C_BUS_1="$(echo ${CAM_ENT_1} | cut -d" " -f2 | cut -b1)"
CAM_I2C_ADRESS_1="$(echo ${CAM_ENT_1} | cut -d" " -f2 | cut -b4-6)"

if [ "$PROC" = "ISI" ] ; then
	VID_DEVICE_2="/dev/video-isi-csi2"
elif [ "$PROC" = "ISP" ] ; then
	VID_DEVICE_2="/dev/video-isp-csi2"
else
	echo ""
	echo "$PROC not supported, only ISI and ISP."
	return 1
fi

if [ -L /dev/cam-csi2 ] ; then
        CAM_DEVICE_2="/dev/cam-csi2"
elif [ -L /dev/cam-csi2-port0 ] ; then
        CAM_DEVICE_2="/dev/cam-csi2-port0"
elif [ -L /dev/cam-csi2-port1 ] ; then
        CAM_DEVICE_2="/dev/cam-csi2-port1"
else
        echo ""
        echo " No camera found on CSI2"
        return 1
fi

CAM_ENT_2="$(cat /sys/class/video4linux/$(readlink ${CAM_DEVICE_2})/name)"
CAM_NAME_2="$(echo ${CAM_ENT_2} | cut -d" " -f1)"
CAM_I2C_BUS_2="$(echo ${CAM_ENT_2} | cut -d" " -f2 | cut -b1)"
CAM_I2C_ADRESS_2="$(echo ${CAM_ENT_2} | cut -d" " -f2 | cut -b4-6)"

echo ""
echo " camera 1 = $CAM_NAME_1 at i2c bus=$CAM_I2C_BUS_1 with i2c adress=0x$CAM_I2C_ADRESS_1 installed"
echo " capture device 1 @CAM1 = ${VID_DEVICE_1} --> $(readlink -f ${VID_DEVICE_1})"
echo " camera device 1 @CAM1 = ${CAM_DEVICE_1} --> $(readlink -f ${CAM_DEVICE_1})"
echo " camera entity name 1 = $CAM_ENT_1"
echo " camera driver 1 = $CAM_NAME_1"
echo ""
echo " camera 2 = $CAM_NAME_2 at i2c bus=$CAM_I2C_BUS_2 with i2c adress=0x$CAM_I2C_ADRESS_2 installed"
echo " capture device 2 @CAM2 = ${VID_DEVICE_2} --> $(readlink -f ${VID_DEVICE_2})"
echo " camera device 2 @CAM2 = ${CAM_DEVICE_2} --> $(readlink -f ${CAM_DEVICE_2})"
echo " camera entity name 2 = $CAM_ENT_2"
echo " camera driver 2 = $CAM_NAME_2"
echo ""

}
