#!/bin/sh

source /root/gstreamer-examples/func.sh

init_dual_dev ISP
[ $? -ne 0 ] && exit 1

source /usr/share/phytec-gstreamer-examples/ar0234.conf
SENSOR_RES="1920x1080"
FRAME_SIZE="width=1920,height=1080"

echo " ================================================================================="
echo " starting gstreamer with two (CAM1 and CAM2) COLOR (YUV) Source after ISP ..."
echo " read from sensor $SENSOR_RES, read after ISP $FRAME_SIZE_FROM_ISP, convert and write to framebuffer"
echo " ================================================================================="
echo ""
echo " choose right XML-File and JSON-File in Sensor0/1_Entry.cfg"
echo " =========================================================="

sed -i 's/^mode= .*/mode= '$MODE_VAR_DEFAULT'/' $(readlink -f /opt/imx8-isp/bin/Sensor0_Entry.cfg)
XML_FILE1=`grep -A1 mode.$MODE_VAR_DEFAULT /opt/imx8-isp/bin/Sensor0_Entry.cfg | grep xml | cut -c12- | sed 's/"//g'`
JSON_FILE1=`grep -A2 mode.$MODE_VAR_DEFAULT /opt/imx8-isp/bin/Sensor0_Entry.cfg | grep json | cut -c12- | sed 's/"//g'`
echo " XML_File1 for ISP at CAM1  = $XML_FILE1"
echo " JSON_File1 for ISP at CAM1 = $JSON_FILE1"

sed -i 's/^mode= .*/mode= '$MODE_VAR_DEFAULT'/' $(readlink -f /opt/imx8-isp/bin/Sensor1_Entry.cfg)
XML_FILE2=`grep -A1 mode.$MODE_VAR_DEFAULT /opt/imx8-isp/bin/Sensor1_Entry.cfg | grep xml | cut -c12- | sed 's/"//g'`
JSON_FILE2=`grep -A2 mode.$MODE_VAR_DEFAULT /opt/imx8-isp/bin/Sensor1_Entry.cfg | grep json | cut -c12- | sed 's/"//g'`
echo " XML_File2 for ISP at CAM2  = $XML_FILE2"
echo " JSON_File2 for ISP at CAM2 = $JSON_FILE2"

echo ""
echo " configure CSI1 (CAM1 port) with media_control"
echo " ============================================="

if [ -e /dev/phycam-deserializer-csi1 ] && [ -e /dev/phycam-serializer-csi1 ] ; then
	DESERIALIZER="$(cat /sys/class/video4linux/$(readlink /dev/phycam-deserializer-csi1)/name)"
	SERIALIZER="$(cat /sys/class/video4linux/$(readlink /dev/phycam-serializer-csi1)/name)"
	media-ctl -l "'${SERIALIZER}':1->'${DESERIALIZER}':0[1]"
fi

if [ -e /dev/phycam-deserializer-csi2 ] && [ -e /dev/phycam-serializer-csi2 ] ; then
	DESERIALIZER="$(cat /sys/class/video4linux/$(readlink /dev/phycam-deserializer-csi2)/name)"
	SERIALIZER="$(cat /sys/class/video4linux/$(readlink /dev/phycam-serializer-csi2)/name)"
	media-ctl -l "'${SERIALIZER}':1->'${DESERIALIZER}':0[1]"
fi


echo ""
echo " configure camera @CAM1 with v4l2_control"
echo " ========================================"

if [ "$(v4l2-ctl ${CAM_DEVICE_1} --get-subdev-fmt 0 | grep "Mediabus Code" | sed 's/.*BUS_FMT_\([A-Z]*\).*/\1/g')" = "Y" ]; then
	V4L2_CTRL_CAM_BW_ISP="v4l2-ctl -d ${CAM_DEVICE_1} ${V4L2_CTRL_CAM1_BW_ISP:13}"
	$V4L2_CTRL_CAM_BW_ISP
	V4L2_CTRL_CAM_BW_ISP="v4l2-ctl -d ${CAM_DEVICE_2} ${V4L2_CTRL_CAM1_BW_ISP:13}"
	$V4L2_CTRL_CAM_BW_ISP
else
	V4L2_CTRL_CAM_COL_ISP="v4l2-ctl -d ${CAM_DEVICE_1} ${V4L2_CTRL_CAM1_COL_ISP:13}"
	$V4L2_CTRL_CAM_COL_ISP
	V4L2_CTRL_CAM_COL_ISP="v4l2-ctl -d ${CAM_DEVICE_2} ${V4L2_CTRL_CAM1_COL_ISP:13}"
	$V4L2_CTRL_CAM_COL_ISP
fi


echo ""
echo " start gstreamer"
echo " ==============="

gst-launch-1.0 imxcompositor_g2d name=mix sink_0::xpos=0 sink_0::ypos=0 sink_1::xpos=1920 sink_1::ypos=0 ! waylandsink sync=false \
	v4l2src device=$VID_DEVICE_1 ! \
	video/x-raw,format=YUY2,$FRAME_SIZE,framerate=30/1 ! mix. \
	v4l2src device=$VID_DEVICE_2 ! \
	video/x-raw,format=YUY2,$FRAME_SIZE,framerate=30/1 ! mix.
